@@ -5,14 +5,10 @@
 __all__ = ['compress_page']
 
 
-from .middleware import CompressionMiddleware, NoCompressionMiddleware
+from .middleware import CompressionMiddleware
 from django.utils.decorators import decorator_from_middleware
 
 
 compress_page = decorator_from_middleware(CompressionMiddleware)
 compress_page.__doc__ = "Decorator to compress the view response if the client supports it."
 
-
-nocompress_page = decorator_from_middleware(NoCompressionMiddleware)
-nocompress_page.__doc__ = "Decorator to indicate that the view response should not be compressed."
-
